package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````*24```````!``````````'"Q````
M`````````$``.``,`$``&0`8``8````$````0`````````!``````````$``
M````````H`(```````"@`@````````@``````````P````0```#@`@``````
M`.`"````````X`(````````9`````````!D``````````0`````````!````
M!````````````````````````````````````$@8````````2!@`````````
M$`````````$````%`````"``````````(``````````@````````NC$`````
M``"Z,0`````````0`````````0````0`````8`````````!@`````````&``
M```````T1P```````#1'`````````!`````````!````!@```/"K````````
M\+L```````#PNP```````'@$````````0`4`````````$`````````(````&
M````"*P````````(O`````````B\````````X`$```````#@`0````````@`
M````````!`````0``````P`````````#``````````,````````P````````
M`#``````````"`````````!3Y71D!``````#``````````,``````````P``
M`````#``````````,``````````(`````````%#E=&0$````Y*````````#D
MH````````.2@````````[`````````#L``````````0`````````4>5T9`8`
M````````````````````````````````````````````````````````$```
M``````!2Y71D!````/"K````````\+L```````#PNP```````!`$````````
M$`0````````!`````````"]L:6(O;&0M;75S;"UX.#9?-C0N<V\N,0``````
M````!````"`````%````1TY5``$``<`$`````0`````````"``'`!`````$`
M````````$0```#\````$````"````"`<$``%0`2"*``0!("&`(2"(0`@20($
M";B"&4&Z!`(*/P```$````!$````2````$D```!/````4````%(`````````
M5@```%<```!8````60```%L```!=``````````````"CZ1D$:G^:?.K3[P[.
MWD<M;\7?'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MO0OK7A^)'
MQ@&[XY)\5<,\TL2YG$!GK\QF./*+',2)!9"(!W#30T75[#-BV^T5C"7,I]VC
M:WZIG)O19<YMX*<""FL:GE`*BA!7H^#[20``````````````````````````
M```````````!````$@`````````````````````````)````$@``````````
M``````````````!&`0``$@`````````````````````````7````$@``````
M``````````````````"6`0``$@`````````````````````````?````$@``
M```````````````````````F````$@````````````````````````#*`0``
M$@````````````````````````"B`0``$@`````````````````````````O
M````(`````````````````````````!'````$@``````````````````````
M``!-````$@````````````````````````!4````$@``````````````````
M``````"$`@``$@````````````````````````"B`@``$@``````````````
M``````````#E`0``$@````````````````````````!;````$@``````````
M``````````````!K`@``$@````````````````````````!B````$@``````
M``````````````````!J````$@````````````````````````!]`@``$@``
M``````````````````````!R````$@````````````````````````!4`@``
M$@````````````````````````!Z````$@````````````````````````"`
M````$@````````````````````````")````(```````````````````````
M``"4`@``$@````````````````````````"E````$@``````````````````
M``````"J````$@````````````````````````!C`0``%@``````````````
M``````````!R`@``$@`````````````````````````2`@``$@``````````
M``````````````"Q````$@`````````````````````````$`@``$@``````
M```````````````````2`P``$@`````````````````````````V`@``$@``
M``````````````````````"Y`@``$@````````````````````````"X````
M$@````````````````````````!4`0``$@````````````````````````#0
M````(`````````````````````````#F````$@``````````````````````
M``"Q`@``$@`````````````````````````B`@``$@``````````````````
M``````#K````(`````````````````````````!?`@``$@``````````````
M```````````%`0``$@````````````````````````"'`0``$@``````````
M```````````````*`0``$@````````````````````````!$`@``$@``````
M``````````````````!V`0``$@`````````````````````````0`0``$@``
M```````````````````````A`0``$@````````````````````````#@`0``
M$@````````````````````````![````$@````````````````````````#Q
M`0``$@`````````````````````````K`@``$@``````````````````````
M``";`@``$@````````````````````````",`@``$@``````````````````
M``````#;`0``$@`````````````````````````G`0``$@``````````````
M```````````N`0``$@`````````````````````````_`0``$@``````````
M``````````````#+`@``(0`6`*#`````````"`````````#&`@``$@`+`*`C
M````````B0$```````"W`0``$@`,`+=1`````````0````````!4`P``$@`+
M`-TQ````````%`4`````````!```$@`+`+4X````````3@`````````Q`P``
M$@`+``LM````````!0````````"^`P``$@`(```@`````````0````````!W
M`P``$@`+`/$V````````Q`$```````#D`P``$@`+`!`M````````L`$`````
M``"O`P``$``6`&C```````````````````!"`P``$@`+`$LQ````````D@``
M``````!A`P``$@`+`-`K````````)0````````!I`P``$@`+``0Q````````
M,`````````"-`P``$@`+`&A/````````#0$```````"B`P``$@`+`,`N````
M````*@````````#[`P``$``6`##!``````````````````#W`@``$@`+`#\E
M````````(P````````#,`@``$0`6`*#`````````"`````````#$`P``$@`+
M`.HN````````V``````````0````$0`2``"\````````"`````````#-`@``
M(0`6`*#`````````"`````````"8`P``$0`5`&#`````````"`````````#=
M`P``$``5`&C```````````````````"T`P``$``+`"DE````````````````
M``"[`P``$@`+`")/````````1@````````#.`@``(0`6`*#`````````"```
M`````````P``$@`+`#0Q````````%P````````#!````(@``````````````
M```````````;`P``$@`+`"LL````````X`````````#Q`P``$@`+`'50````
M````0@$```````"]`0``$0`6`(#``````````0````````#0`P``$@`+`,(O
M````````0@$`````````;W!E;F1I<@!M96UC;7``<W1D97)R`')E86QL;V,`
M86-C97-S`'-N<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K
M`&=E='!I9`!S=')C;7``=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!S=')R8VAR
M`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O
M<&5N`'-T<G-T<@!S=')C:'(`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`7U]R
M96=I<W1E<E]F<F%M95]I;F9O`&5X:70`7TE435]R96=I<W1E<E1-0VQO;F54
M86)L90!R96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`<W1R;&5N
M`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S
M>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`
M<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E
M>'0`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?
M9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E
M<WES;6%L;&]C`'!E<FQ?86QL;V,`<W1R8W!Y`')E861D:7(`<W!R:6YT9@!S
M=')D=7``<W1R=&]K`'!T:')E861?871F;W)K`&9P<FEN=&8`7U]L:6)C7W-T
M87)T7VUA:6X`7U]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UX.#9?
M-C0N<V\N,0!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T
M=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P
M87)?8F%S96YA;64`7U]B<W-?<W1A<G0`<VAA7VEN:70`<&%R7V1I<FYA;64`
M<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]E
M;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`
M````````\+L````````(`````````$`F````````^+L````````(````````
M`.`E`````````,`````````(``````````#`````````(,`````````(````
M`````.)@````````*,`````````(`````````-M@````````,,`````````(
M`````````!-B````````.,`````````(`````````/A@````````0,``````
M```(`````````!MB````````8,`````````(`````````*MB````````L+\`
M```````&````"@``````````````N+\````````&````&@``````````````
MP+\````````2````'@``````````````R+\````````&````6@``````````
M````T+\````````&````*```````````````V+\````````&````+```````
M````````X+\````````&````,0``````````````Z+\````````&````,@``
M````````````\+\````````&````-P```````````````+P````````%````
M4@``````````````@,`````````%````70``````````````H,`````````%
M````4````````````````+X````````'`````0``````````````"+X`````
M```'`````@``````````````$+X````````'`````P``````````````&+X`
M```````'````!```````````````(+X````````'````!0``````````````
M*+X````````'````!@``````````````,+X````````'````!P``````````
M````.+X````````'````"```````````````0+X````````'````"0``````
M````````2+X````````'````"P``````````````4+X````````'````#```
M````````````6+X````````'````#0``````````````8+X````````'````
M#@``````````````:+X````````'````#P``````````````<+X````````'
M````$```````````````>+X````````'````$0``````````````@+X`````
M```'````$@``````````````B+X````````'````$P``````````````D+X`
M```````'````%```````````````F+X````````'````%0``````````````
MH+X````````'````%@``````````````J+X````````'````%P``````````
M````L+X````````'````&```````````````N+X````````'````&0``````
M````````P+X````````'````&P``````````````R+X````````'````'```
M````````````T+X````````'````'0``````````````V+X````````'````
M'P``````````````X+X````````'````(```````````````Z+X````````'
M````(0``````````````\+X````````'````(@``````````````^+X`````
M```'````(P```````````````+\````````'````)```````````````"+\`
M```````'````)0``````````````$+\````````'````)@``````````````
M&+\````````'````)P``````````````(+\````````'````*0``````````
M````*+\````````'````*@``````````````,+\````````'````*P``````
M````````.+\````````'````+0``````````````0+\````````'````+@``
M````````````2+\````````'````+P``````````````4+\````````'````
M,```````````````6+\````````'````,P``````````````8+\````````'
M````-```````````````:+\````````'````-0``````````````<+\`````
M```'````-@``````````````>+\````````'````.```````````````@+\`
M```````'````.0``````````````B+\````````'````.@``````````````
MD+\````````'````.P``````````````F+\````````'````/```````````
M````H+\````````'````/0``````````````J+\````````'````/@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!06,,`````````````````_S7:G0``_R7<G0``#Q]``/\EVIT``&@`````
MZ>#_____)=*=``!H`0```.G0_____R7*G0``:`(```#IP/____\EPIT``&@#
M````Z;#_____);J=``!H!````.F@_____R6RG0``:`4```#ID/____\EJIT`
M`&@&````Z8#_____):*=``!H!P```.EP_____R6:G0``:`@```#I8/____\E
MDIT``&@)````Z5#_____)8J=``!H"@```.E`_____R6"G0``:`L```#I,/__
M__\E>IT``&@,````Z2#_____)7*=``!H#0```.D0_____R5JG0``:`X```#I
M`/____\E8IT``&@/````Z?#^____)5J=``!H$````.G@_O___R52G0``:!$`
M``#IT/[___\E2IT``&@2````Z<#^____)4*=``!H$P```.FP_O___R4ZG0``
M:!0```#IH/[___\E,IT``&@5````Z9#^____)2J=``!H%@```.F`_O___R4B
MG0``:!<```#I</[___\E&IT``&@8````Z6#^____)1*=``!H&0```.E0_O__
M_R4*G0``:!H```#I0/[___\E`IT``&@;````Z3#^____)?J<``!H'````.D@
M_O___R7RG```:!T```#I$/[___\EZIP``&@>````Z0#^____)>*<``!H'P``
M`.GP_?___R7:G```:"````#IX/W___\ETIP``&@A````Z=#]____)<J<``!H
M(@```.G`_?___R7"G```:",```#IL/W___\ENIP``&@D````Z:#]____);*<
M``!H)0```.F0_?___R6JG```:"8```#I@/W___\EHIP``&@G````Z7#]____
M)9J<``!H*````.E@_?___R62G```:"D```#I4/W___\EBIP``&@J````Z4#]
M____)8*<``!H*P```.DP_?___R5ZG```:"P```#I(/W___\E<IP``&@M````
MZ1#]____)6J<``!H+@```.D`_?___R5BG```:"\```#I\/S___\E6IP``&@P
M````Z>#\____)5*<``!H,0```.G0_/___R5*G```:#(```#IP/S___\E0IP`
M`&@S````Z;#\____)3J<``!H-````.F@_/___R4RG```:#4```#ID/S___\E
M*IP``&:0_R4ZG```9I#_)3J<``!FD```````````4TB#["")?"0<2(U\)!Q(
MB70D$$B-="002(E4)`A(C50D".B)_O__2(LU(IP``$B+/1.<``!(B?+H$_W_
M_X`]G)P```!(BQW5FP``=2[HWOW__TB)!2^=``!(B<=(A<!U"K\!````Z%7^
M___HH/[__V1(BP/&@-<)````9$B+`XM\)!R`B"H$```#C5\#@\<$2&/_2,'G
M`^A4_O__2(MT)!"+?"0<2(G!2(D%T9P``$B+!DB)`4B-!4D^``!(B4$(2(L%
M^9L``$B)01!(C04V/@``2(E!&#'`C5`$2/_`2&/22(T4T3G'?@E,BP3&3(D"
MZ^8QP$B+/8V<``!%,<!(C350!P``2(D"B=KHP?S__XG#A<!U#DB+/6R<``#H
MO_W__XG#2(L]7IP``.A1_?__,<!(C3V].P``Z"`"``!(A<!U+DB#/2Z<````
M=1-(C3U7.P``Z`4"``!(B049G```2(L]$IP``$B%_W0%Z*43``!(BST1G```
MZ"3^___H'_O__TB#Q"")V%O#2#'M2(GG2(TUTI8``$B#Y/#H`````(LW2(U7
M"$R-!6LL``!%,<E(C0VJ^O__2(T]0_[__^G._/__9BX/'X0```````\?0`!(
MC3WQF@``2(T%ZIH``$@Y^'052(L%+IH``$B%P'0)_^`/'X``````PP\?@```
M``!(C3W!F@``2(TUNIH``$@I_DB)\$C![C](P?@#2`'&2-'^=!1(BP4-F@``
M2(7`=`C_X&8/'T0``,,/'X``````\P\>^H`]U9H```!U0U5(@SW2F0```$B)
MY70,2(L]_ID``.B!_?__Z&3___](@SV<F0```'0,2(T]"WP``.A>_?__Q@67
MF@```5W##Q]$``##9F8N#Q^$```````/'T``\P\>^DB#/829````=")52(TU
MBIH``$B-/<M[``!(B>7H*_W__UWI-?___P\?1```Z2O___]!5T%6055!5%4Q
M[5-12(7_=&=,BS42F@``387V=%M)B?U)B?=(B?B*$(32=`J`^CUT!4C_P.OP
M1"GH38GT2&/828LL)$B%[70P2(G:3(GN2(GOZ'3Z__^%P'48@'P=`#UU$4TI
M]$B-;!T!2<'\`T6))^L&28/$".O'6DB)Z%M=05Q!74%>05_#2(/L&&1(BP0E
M*````$B)1"0(,<!(C70D!.A:____2(M4)`AD2"L4)2@```!T!>@P_/__2(/$
M&,-54TB)^TB#[!AD2(L$)2@```!(B40D"#'`2(UL)`0QP$B)[DB)W^@5____
M2(7`=")(8U0D!$B+!2^9``!(C0302(M0"$B)$$B%TG322(/`".ON2(M$)`AD
M2"L$)2@```!T!>C$^___2(/$&%M=PTB![+@```!D2(L$)2@```!(B80DJ```
M`#'`2(UT)!A(B7PD".BT^?__A<!U,XM4)#!(BWPD"('B`/```('Z`$```'0(
M@?H`H```=1:^`@```.AW^/__A<`/E,`/ML#K`C'`2(N4)*@```!D2"L4)2@`
M``!T!>A#^___2('$N````,-!5D%505154TB![*````!D2(L$)2@```!(B80D
MF````#'`2(7_#X3B````@#\`2(G]#X36````Z+_W__],C2V9-P``28G$2(7`
M#X2^````3(GGZ&3X__](A<`/A)T```!(C5@33(GN2(G?Z#SX__^%P'3<2(TU
M83<``$B)W^@I^/__A<!TR4B)[^B=^O__2(G?28G&Z)+Z__]!C7P&`DAC_^A5
M^/__2(G92(GJ2(TU*S<``$F)QDB)QS'`Z$OZ__],B?=(C70D".@.^O__3(GW
M_\!T%XM$)"`E`/```#T`0```=0?H%____^L%Z/OW__],B??HT_G__^E2____
M3(GGZ&;X__](B>_HCOG__TB+A"28````9$@K!"4H````=`7H%OK__TB!Q*``
M``!;74%<05U!7L-!5KH"````,?9,C37FE@``055!5$&)_%532('L$``!`&1(
MBP0E*````$B)A"0(``$`,<#H'O?__[D```$`2(U8_TB)V$B92/?Y2"G32(7;
M>%XQTDB)WD2)YTF)Y>CU]O__N@@``0!,B>Y$B>?HU?C__TB828UL!?A(@_@'
M=BA,.>UR([H(````3(GV2(GOZ$/V__^%P'4*3"GM2(U$'0#K$DC_S>O82('K
M```!`.N=2(/(_TB+E"0(``$`9$@K%"4H````=`7H._G__TB!Q!```0!;74%<
M05U!7L-!5T%6055!5%5(B?U32(GS2(/L&&1(BP0E*````$B)1"0(,<"`/CUU
M`TC_PTB)W^CG^/__2(UT)`1(B>])B<0QP.CZ^___28G%2(7`="=(B<?HQ?C_
M_TPYX`^"J0```#'`BA0#08A4!0!(_\"$TG7QZ0(!``!,BSWOE0``,<!)B<5(
MC4`!2X,\[P!U\D&-=0)(8_9(P>8#@ST]E@```'093(G_Z'/U__](B06\E0``
M2(7`=3SIO@```,<%&)8```$```!(B??H(/;__TF)QDB%P`^$H````$ECU4R)
M_DB)QTC!X@/H$O;__TR)-7N5``!(BQ5TE0``08U%`3')1(EL)`1(F$B)#,)(
MB>B*$(32=`J`^CUT!4C_P.OP2"GH3&-L)`1(BQ5!E0``2)A)C7P$`DZ--.KH
ML?7__TF)!DB%P'0U2(L%(I4``$J+!.B*50!(_\5(B<%(_\"(4/^`^CUT!(32
M=>C&`3TQTHH,$X@,$$C_PH3)=?-(BT0D"&1(*P0E*````'0%Z)_W__](@\08
M6UU!7$%=05Y!7\-(BP7IDP``2(L5`I0``$B-#?-T``!(C34=-```9$B+..D;
M]___4TB+'<.3``!D2(L[Z,K___]D2(L[13')6TR-!8\V``!(C175"@``3(G!
M2(TU_S,``.EE]/__55-(@>P8(```9$B+!"4H````2(F$)`@@```QP$B-;"0&
MZ&_T__],C07B,P``O@$0``!(B>^)P4B-%=4S```QP.@0]/__@_C_=00QP.MP
M2)A(/0`0``!V`@\+2(V<)`<0``!(B>^Z`!```$B)WNBC]?__2(G%A<!XT8UX
M`4AC_^AQ]/__2(7`=,%(8]5(.=AS"4B-#!!(.<MROD@YPW,)2(T,$T@YR'*P
M@?T!$```?ZB)T4B)QTB)WO.DQ@00`$B+E"0((```9$@K%"4H````=`7H7_;_
M_TB!Q!@@``!;7</I&____T%7059!54%454B)_4B-/2<S``!32(GS2('LJ!``
M`&1(BP0E*````$B)A"28$```,<#HM_G__[XO````2(GO28G%Z)KT__](A<!T
M%DB)[DB-/>XR```QP.C)_/__Z2(!``!(B=],C37E,@``3(T]?S(``.@9]/__
M3(GV2(G'Z([U__](B<-(A=MTP8`[`'4#3(G[387M=!-(B=Y,B>_H'O/__X7`
M#X3'````2(G?Z([U__](C40#_T@YPW,-@#@O=0C&``!(_\CK[DB)W^AO]?__
M2(GO28G$Z&3U__])C40$`4@]_P\```^'7O___TR-I"28````28GI2(G9,<!,
MC05.,@``2(T5*S,``+X`$```3(GGZ%CR____P#T`$```=@(/"TB-="0(3(GG
MZ,#T__^%P'4]BT0D("4`\```/0"```!U+;X!````3(GGZ`_R__^%P'4<3(GF
M2(T]Y#$``.C!^___3(GGZ"3S__](B<7K$DR)]C'_Z)7T__](B</I`O___TB+
MA"28$```9$@K!"4H````=`7HM?3__TB!Q*@0``!(B>A;74%<05U!7D%?PTB#
M[!B^+P```$B)?"0(Z(WR__](BWPD"$B%P'0$2(UX`4B#Q!CIMO+__U532('L
M&!```&1(BP0E*````$B)A"0($```,<!(A?]T68`_`$B)_711Z#CT__](_\!(
M/0`0``!W>TB-7"0(2(GN2(G?Z!WR__](B=_H%?3__TB-1`/_2#G#<PV`."]U
M",8``$C_R.ONOB\```!(B=_H`?+__TB%P'4H2(N$)`@0``!D2"L$)2@```!U
M/$B!Q!@0``!(C3U\,```6UWI%/+__T@YPW,#Q@``2(G?Z`3R___K`C'`2(N4
M)`@0``!D2"L4)2@```!T!>BH\___2('$&!```%M=PT%5,<!(C3V7,```3(TM
MUS```$%43(TE;3```%5(C2V\,```4TB-'9@P``!1Z$+W__\QP$B-/7$P``#H
M-/?__S'`2(T]:S```.@F]___,<!(C3UF,```Z!CW__\QP$B)W^@.]___,<!(
MC3UE,```Z`#W__\QP$R)Y^CV]O__,<!(B>_H[/;__S'`3(GOZ.+V__\QP$B-
M/5DP``#HU/;__S'`2(T]Z2\``.C&]O__,<!(C3U',```Z(#V__](A<!T#4B)
MQDR)[S'`Z*;Y__](C3TZ,```,<#H8/;__TB)QDB%P'0.2(T]-C```#'`Z(+Y
M__](C3TS,```,<#H//;__TR)YTB)QDB%P'492(T]*C```#'`Z"/V__](B<9(
MA<!T"DB)[S'`Z$GY__]:2(G?2(TU%S```%LQP%U!7$%=Z3'Y__]12(T]E2\`
M`#'`Z.KU__](B<(QP$B%TG05BA*`^C`/E,"$T@^4P@G0@_`!#[;`6L-1Z#;R
M__^)Q^C/\/__2(7`=`-(BP!:PT%53(TMO"\``#'`05152(G]3(GO4U'HE_7_
M_TB)[DB%P'16@#@`2(G#=$Y(B<?H0O#__TB%P'522(GOZ,7Q__](B=])B<3H
MNO'__TF-?`0"Z(#O__](C36?+P``28G82(GJ28G$2(G'2(T-IBX``#'`Z&_Q
M__],B>9:3(GO6S'`74%<05WI8/C__UA;74%<05W#05<Q]DF)_[D,````059!
M54%455-(@>Q(`0``9$B+!"4H````2(F$)#@!``!(C047+P``2(U\)$A(B70D
M*$B--?^-``#SI3'_2(E\)$!(C3T9+@``2(E$)!A(C07$+0``2(E$)"!(C07C
M+@``2(E$)#!(C07<+@``2(E$)#@QP.B<]/__2(7`=$"`.`!(B<-T.$B)Q^C5
M_O__2(N$)#@!``!D2"L$)2@````/A4H$``!(@<1(`0``2(G?6UU!7$%=05Y!
M7^GZ[O__,<!(C6PD,.B"_O__2(G#2(7`=3=(BWT`2(7_="<QP.@S]/__2(G'
M2(7`=!*`.`!T#>C$[O__2(G#2(7`=0U(@\4(Z]!(C1TO+@``2(G?2(TM/RX`
M`.A0\/__2(U\``'H%N[__TF)Q4F)Q`^V$X32=!9,B>=(B>XQP$C_P^@)\/__
M28/$`NOC2(UL)$A,BV4`387D="Y,B><QP.BX\___2(G#2(7`=".`.`!T'DB)
MQ^A)]/__A<!T$DB)W^@Z[O__28G$2(U<)!CK+TB#Q0CKO$B+*TB%[70H@'T`
M`'0E2(GO2(U;".@3]/__A<!TXDB)[^@$[O__28G$387D=-+K`T4QY$R)YTR-
M-:\L``#HF.___TR)[TB)P^B-[___C:P#!`0``$AC[4B)[^A+[?__38GI3(GQ
M3(GB2(G'2(D$)#'`3(T%42T``$B--4\M``#H-N___TB+/"2^P`$``.C8[O__
M_\!U+.B_[O__1(L`08/X$70>2(L,)$F+%TB--24M```QP$B+/<^'``#H.N[_
M_^M$2(L\)$B-="1XZ#KM__]!B<6%P'43BX0DD````"4`\```/0!```!T(TB+
M#"1)BQ=(C34:+0``,<!(BSV)AP``Z/3M__\Q[>E!`@``1(ND))0```#HX.[_
M_T$YQ'7+BX0DD````"7_`0``/<`!``!UN$B)[^AP[/__2(T]9"P``$B)Q3'`
MZ#SR__](B<9(A<!U!4V+)^L028L_Z#KX__])B<1(A<!TZTR)Y^AJ[O__2(G#
M@_@#?E=(F$B-->0L``!)C7P$_.C/Z___A<!U0(/[!'0-C5/[2&/208`\%"]U
M+DV+?PA-A?]T)4R)_^@H[O__2(/X`W8728U\!_Q(C36F+```Z)'K__^%P$T/
M1.<QP.BX^___A<`/A<(```!,B><Q]NA2[/__08G$A<`/A*T```")Q^CJ\___
M2(G#2(7`#XB:````,=)(C7#V1(GGZ";K__],C;PD"0$``+H&````1(GG3(G^
MZ/[L__^Z!@```$B--2)K``!,B?_H>NK__X7`=5Q(C7/.,=)$B>?HZ.K__TR-
MA"0/`0``1(GGNB@```!,B<9,B40D".B[[/__3(M$)`A(BQ0D,<!,C0VM+```
M3(GQ2(TUY"L``$B)[\:$)#<!````Z!_M___IC````$B--?$J``!(C3U]*@``
M,<#H"O3__TR-)7(L``#HB>K__TB+%"1,B?%(B>]!B<!,C0U9+```2(TUHBL`
M`#'`Z-?L__^^P`$``$B)[^AZ[/___\!U..AA[/__@S@1=2[H1^K__T'_Q4R)
M\4B)[T&)P%!%B>E(C35R*P``051(BU0D$#'`Z)+L__]:6>NW2(L\).A%[/__
M2(T]F"D``$B)[C'`Z'GS__](B>_HA_K__TB+A"0X`0``9$@K!"4H````=`7H
MA.S__TB!Q$@!``!(B>A;74%<05U!7D%?PT%42(T]BRD``%532(L=O8@``&1(
MBP.*D+````"(D+$````QP.CC[___2(7`=`N`.#%U!H!X`0!T!S'`Z)'X__]D
M2(L[N0,```"Z`0```$B--=DJ``#HE>K__TB)Q4B%P'0M2(M`$&1(BSM(C16_
M*@``2(LPZ);J__](BT402(LP]D8.0'0)9$B+.^B`Z?__9$B+.[D#````N@$`
M``!(C361*@``Z$;J__])B<1(A<!T7DB-/:HH```QP.A-[___2(G"2(7`=`M)
MBT0D$&1(BSOK->AC]/__9$B+.TB%P$B)Q4F+1"00=!5(BS!(B>KH'.K__TB)
M[^@$Z___ZQ)(BQ4KB0``2(L22(LPZ`#J__]D2(L[N@$```!(C348*@``Z$OH
M__]D2(L[2(T5'2H``$B)QNC8Z?__9$B+`TB-/1<H``#&@+$`````,<#HO.[_
M_TB)!="(``!(A<!U)$B+/<R(``#HA/G__TB)!;B(``!(A<!U#$B-/=<I``#H
M+^C__TB+/:"(``"^P`$``.A>ZO__B<&-0`&#^`%V)(/Y$70?2(L%B(@``$B+
M%7F(``!(C3V^*0``2(LP,<#H\.?__UM=05S#55-(B?M1Z"KV__](B<?H^/7_
M_TB)Q3'`Z#+X__^%P'0I2(7;="2`.P!T'TB--5@H``!(B>_HT>C__T@YQ74+
M6DB)WUM=Z2;O__]86UW#05=(B?XQTD%6055!5%532('LF`(``&1(BP0E*```
M`$B)A"2(`@``,<"+1!8X2(M\%C@/R(G`2(GY2(E$5`A(B?A(P>D@2,'H*$C!
M[S@E`/\``$@)^$B)STC!X0A(P><8@>$``/\`B?]("?A("<A(B414$$B#P@A(
M@_I`=:Q(C50D"$B-O"0(`@``2(M":$@S0D!(@\((2#-""$@S0OA(C0P`2,'H
M'PG(2(E">$@Y^G793(L.3(M>$$B+?B!(BUX83(G(3(G*2(MN"$B+3"002,'J
M&TC!X`5("=`#1"0(2(V,"YEY@EJ-E#B9>8):3(G82#'82"'H2#'81(T4`DB)
MZDB)Z$C!Z`)(P>(>3(G72`G"3(G82,'O&T&)T$PQP$PAR$PQV$@!R$R)T4C!
MX05("?E(BWPD&$2-)`A,B<A,B<E(P>D"2,'@'DF-O#N9>8):38GE2`G(2<'M
M&T@QPHG!3"'23#'"2`'Z3(GG2,'G!4P)[TR+;"0@`==,B=))P>H"2,'B'HG_
M3XV$*)EY@EI,"=))B?U(,=!!B=),(>!)P>T;2#'(3`'`28GX2<'@!4T)Z$R+
M;"0H00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1(
M(?I,,=)(`<I,B<%(P>$%3`GI3(ML)#`!T4B)^DC![P)(P>(>B<E/C90JF7F"
M6D@)^DF)S4@QT$G![1N)UTPAP$PQX$P!T$F)RDG!X@5-">I,BVPD.$$!PDR)
MP$G!Z`)(P>`>18G23XVD+)EY@EI,"<!-B=5(,<))P>T;08G`2"'*2#'Z3`'B
M38G42<'D!4T)[$R+;"1`00'42(G*2,'I`DC!XAY%B>1*C;POF7F"6D@)RDV)
MY4@QT$G![1N)T4PAT$PQP$@!^$R)YTC!YP5,">],BVPD2`''3(G02<'J`DC!
MX!Z)_T^-A"B9>8):3`G028G]2#'"2<'M&T&)PDPAXD@QRDP!PDF)^$G!X`5-
M">A,BVPD4$$!T$R)XDG![`)(P>(>18G`2HV,*9EY@EI,">)-B<5(,=!)P>T;
M08G42"'X3#'02`'(3(G!2,'A!4P)Z4R+;"18`<%(B?A(P>\"2,'@'HG)3XV4
M*IEY@EI("?A)B<U(,<))P>T;B<=,(<),,>),`=))B<I)P>(%30GJ3(ML)&!!
M`=),B<))P>@"2,'B'D6)TD^-I"R9>8):3`G"38G52#'02<'M&T&)T$@AR$@Q
M^$P!X$V)U$G!Y`5-">Q,BVPD:$$!Q$B)R$C!X!Y(P>D"18GD2HV\+YEY@EI(
M"<A-B>5(,<))P>T;B<%,(=),,<)(`?I,B>=(P><%3`GO3(ML)'`!UTR)TDG!
MZ@)(P>(>B?]/C80HF7F"6DP)TDF)_4@QT$G![1M!B=),(>!(,<A,`<!)B?A)
MP>`%30GH3(ML)'A!`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"
M2<'M&T&)Q$@A^DPQTD@!RDR)P4C!X05,">E,BZPD@`````'12(GZ2,'B'DC!
M[P*)R4^-E"J9>8):2`GZ28G-2#'02<'M&XG73"'`3#'@3`'028G*2<'B!4T)
MZDR+K"2(````00'"3(G`2<'H`DC!X!Y%B=)/C:0LF7F"6DP)P$V)U4@QPDG!
M[1M!B<!((<I(,?I,`>)-B=1)P>0%30GL1HTL(DB)RDC!Z0),BZ0DD````$C!
MXAY("<I*C;PGF7F"6DV)[$@QT$G![!N)T4PAT$PQP$@!^$R)[TC!YP5,">=,
MBZ0DF`````''3(G02,'@'DG!Z@*)_T^-A""9>8):3`G028G\2#'"2<'L&T&)
MPDPAZD@QRDP!PDF)^$G!X`5-">!%B<!,`<)-B>A)P>T"2<'@'D&)U$T)Z$R+
MK"2@````3#'`2"'X2HV,*9EY@EI-B>5,,=!)P>T;2`'(3(GA2,'A!4P)Z8G)
M2`'(2(GY2,'O`DC!X1Y!B<5("?E,B<=%B<!(,<\QUTB+E"2H````28V4$J'K
MV6Y-B>I(`==,B>I)P>H;2,'B!4P)THG22`'73(GB2,'B'DG![`)!B?I,`X0D
ML````$P)XDF)S(G)2`.,)+@```!),=1$,>!-C:0`H>O9;DR)T$V)T$G!Z!M(
MP>`%3`G`B<!)`<1,B>A)P>T"2,'@'D6)X$P)Z$F)U8G22`.4),````!),<5$
M,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)
M[TP)T4F)PHG`23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'4
M3(G"2<'H`DC!XAY%B>),"<))B<A(`X0DR````(G)23'02`.,)-````!%,>A.
MC:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(B?A(P>\"2,'@'D6)Z$@)
M^$B)UXG22`.4)-@```!(,<=$,>=,C:0YH>O9;DR)P4R)QTC![QM(P>$%2`GY
MB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$).````!),<I%,>I.C:P2
MH>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"2,'B'D6)ZDP)PDF)
MR(G)23'02`.,).@```!%,>!.C:0`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)
M`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4)/````!(,<=$,>],C:PYH>O9
M;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)[TP)T4F)PHG`
M2`.$)/@```!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=1,
MB<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'KV6Y,B=!-B=!(P>`%
M2<'H&T@#C"0``0``3`G`B<!)`<5(B?A(P>\"2,'@'D6)Z$@)^$B)UXG22`.4
M)`@!``!(,<=$,>=,C:0YH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<Q,B=%)
MP>H"2,'A'D2)YTP)T4F)PHG`2`.$)!`!``!),<I%,>I.C:P2H>O9;DB)^DF)
M^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"2,'B'D6)ZDP)PDF)R(G)23'013'@
M3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P$@#C"08`0``B<!)`<1(B?A(P>\"
M2,'@'D6)X$@)^$B)UXG22`.4)"`!``!(,<=$,>],C:PYH>O9;DR)P4R)QTC!
M[QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)[TP)T4F)PHG`2`.$)"@!``!)
M,<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B
M'D6)XDP)PDF)R(G)23'013'H3HVL`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`
M20'%2(GX2,'@'DC![P)%B>A(`XPD,`$``$@)^$B)UXG22`.4)#@!``!(,<=$
M,>=-B<1(C8PYH>O9;DR)QTG![!M(P><%3`GG38G42<'J`DG!Y!Z)_TT)U$F)
MPD@!^8G`33'BB<](`X0D0`$``$4QZDF)_4Z-E!*AZ]EN2(GZ2<'M&TC!X@5,
M">I!`=),B<))P>@"2,'B'D6)TDP)PDV)X$6)Y$DQT$F)UD&)U40QP4V)T$B-
MC`BAZ]EN3(G02<'H&TC!X`5,"<!$C00!2(GY2,'O`KC<O!N/2,'A'D@)^4D)
MSHG/2"'Z32'620G62(N4)$@!``!(`<),`>)-B<1,`?)-B<9)P>0%2<'N&TT)
M]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G222'^3"'!3`GQ3(NT)%`!
M``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!S4R)P4G!Z`)(P>$>
M18GM3`G!08G(20G.32'F3"'"3`GR3(NT)%@!``!)`<9,`?=-B>Y(`?I,B>])
MP>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)UD&)U$TAQDPAZ4P)
M\4R+M"1@`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-"?))B=9!`<I,B>E)
MP>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"1H`0``20'&30'P38G6
M3`'"38G02<'@!4G![AM-"?!!`=!(B?I(P>\"2,'B'D6)P$@)^D@)T4F)UHG7
M32'N3"'13`GQ3(NT)'`!``!)`<9-`?1-B<9,`>%-B<1)P>X;2<'D!4T)]$F)
MUD$!S$R)T4G!Z@)(P>$>18GD3`G108G*20G.32'&3"'23`GR3(NT)'@!``!)
M`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDC!XAY)P>@"18GM3`G"
M2`G128G608G032'63"'A3`GQ3(NT)(`!``!)`<9,`?=-B>Y(`?E,B>])P>X;
M2,'G!4P)]TF)U@'/3(GA2<'L`DC!X1Z)_TP)X4&)S$D)SDTA[DPAXDP)\DR+
MM"2(`0``20'&30'R28G^3`'228GZ2<'N&TG!X@5-"?)!`=),B>I)P>T"2,'B
M'D6)TDP)ZD@)T4F)UD&)U4@A^4TAYDP)\4R+M"20`0``20'&30'P38G63`'!
M38G02<'N&TG!X`5-"?!)B=9!`<A(B?E(P>\"2,'A'D6)P$@)^8G/20G.32'6
M2"'Z3`GR3(NT))@!``!)`<9-`?1-B<9,`>)-B<1)P>X;2<'D!4T)]$$!U$R)
MTDG!Z@)(P>(>18GD3`G22`G128G608G222'^3"'!3`GQ3(NT)*`!``!)`<9-
M`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!S4R)P4G!Z`)(P>$>18GM3`G!
M08G(20G.32'F3"'"3`GR3(NT)*@!``!)`<9,`?=-B>Y(`?I,B>])P>X;2,'G
M!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)UD&)U$TAQDPAZ4P)\4R+M"2P
M`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-"?))B=9!`<I,B>E)P>T"2,'A
M'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"2X`0``20'&30'P38G63`'"38G0
M2<'N&TG!X`5-"?!!`=!(B?I(P>\"2,'B'D6)P$@)^D@)T4F)UHG732'N3"'1
M3`GQ3(NT),`!``!)`<9-`?1-B<9,`>%-B<1)P>X;2<'D!4T)]$F)UD$!S$R)
MT4G!Z@)(P>$>18GD3`G120G.08G*32'&3"'23`GR3(NT),@!``!)`<9-`?5-
MB>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDG!Z`)(P>(>18GM3`G"2`G128G0
M08G732'03"'A3`G!3(N$)-`!``!)`<!,`<=-B>A(`?E,B>])P>@;2,'G!4P)
MQT2-!#E,B>=)P>P"2(G12,'G'DP)YT&)_$@)^4PAZ4PAXD@)RDB+C"38`0``
M2`'!3`'138G"2`.$).`!``!(`<I,B<%)P>H;3`'X2,'A!4R+O"0@`@``3`G1
MB<E(`<I,B>E)P>T"2,'A'D&)TDP)Z4@)STF)S4&)SDPAQTTAY4D)_4R)UTP!
MZ$V)U4C!YP5)P>T;3`GO38G%2<'H`DG!Y1Z)_TT)Z$R+K"3H`0``2`'X3#'!
MB<<QT;K6P6+*20'530'L28G]3`'A28G\2<'M&TG!Y`5-">Q-B=5%B>1,`>%)
MP>4>2<'J`D&)S$T)ZDV)Q46)P$TQU40QZ$R+K"3P`0``20'530'U38GF3`'H
M38GE2<'N&TG!Y05-"?5)B?Y(P>\"2<'F'D6)[4P)]TR+M"3X`0``3`'H08G%
M20'630'P38G618G223'^1#'Q38GN20'(3(GI2<'N&TC!X05,"?&)R4D!R$R)
MX4G![`)(P>$>18G&3`GA3(ND)``"``!)`=1-`>))B?R)_TDQS$0QX$V)]$D!
MPDR)\$C!X`5)P>P;3`G@B<!)`<),B>A)P>T"2,'@'D6)U$D)Q4B+A"0(`@``
M2`'02`''2(G(B<E,,>A$,<!-B>!(`<=,B>!)P>@;2,'@!4P)P(G`2`''3(GP
M2<'N`DC!X!Y!B?A,"?!,B[0D$`(``$D!UDP!\4V)[D6)[4DQQD4Q\DV)QDD!
MRDR)P4G![AM(P>$%3`GQB<E)`<I,B>%)P>P"2,'A'D6)UDD)S$B+C"08`@``
M2`'120'-2(G!20'73#'A,?E,B?=)`<U,B?%(P>\;2,'A!4@)^8G)20'-3(G!
M2<'H`DC!X1Y$B>],"<%!B<!,B>!%B>1(,<A-`?A,B[PD,`(``$0QT$F)^DD!
MP$B)^$G!ZAM(P>`%3`G0B<!)`<!,B?!)P>X"2,'@'D6)PDD)QDB+A"0H`@``
M2`'020'$2(G(3#'P1#'H38G520'$3(G02<'M&TC!X`5,">B)P$D!Q$B)^$C!
MX!Y(P>\"20'718GE2`GXB<],B?%%B?9(,<%,`?]$,<%-B>A(`<],B>E)P>@;
M2,'A!4P)P8G)2`'/3(G12<'J`DC!X1Y!B?A)"<I(BXPD.`(``$@!T4D!SDB)
MP8G`3#'11#'A38G$20'.3(G!2<'L&TC!X05,">&)R4D!SDR)Z4G![0)(P>$>
M18GT3`GI3(NL)$`"``!)`=5,`>A-B=5%B=)),<U$,>]-B>5(`<=,B>!(P>`%
M2<'M&TP)Z(G`2`''3(G`2<'H`DC!X!Y!B?U)"<!(BX0D2`(``$@!T$D!PDB)
MR(G)3#'`1#'P38GN20'"3(GH2<'N&TC!X`5,"?")P$D!PDR)X$G![`)(P>`>
M18G63`G@3(ND)%`"``!)`=1,`>%-B<1%B<!),<1$,>=-B?1(`<],B?%)P>P;
M2,'A!4P)X8G)2`'/3(GI2<'M`DC!X1Y!B?Q)"<U(BXPD6`(``$@!T4D!R$B)
MP8G`3#'I1#'138GB20'(3(GA2<'J&TC!X05,"=&)R4D!R$R)\4G![@)(P>$>
M18G"3`GQ3(NT)&`"``!)`=9,`?!-B>Y%B>U),<Y$,?=-B=9(`?A,B==)P>X;
M2,'G!4P)]TV)YDG![`))P>8>B?]-"?1,B[0D:`(``$@!^(G'20'630'U28G.
MB<E-,>9%,?!)B?Y-`<5)B?A)P>X;2<'@!4T)\$V)UD6)P$T!Q4G!YAY)P>H"
M18GH30GR3(NT)'`"``!)`=9,`?%-B>9%B>1-,=9$,?!-B<9(`<%,B<!)P>X;
M2,'@!4P)\(G`2`'!2(GX2,'O`DC!X!Y!B<Y("<=(BX0D>`(``$@!T$@#E"2`
M`@``20'$3(G018G22#'X1#'H38GU3`'@38GT2<'M&TG!Y`5-">Q-B<5!`<1)
MP>4>3(G`2,'H`DV)Z$6)Y$D)P$J-!`I(B?I,,<),`=`QRDR)X4@!T$R)XDC!
MX@5(P>D;00'L00'82`G*`WX@3(EF"`'03(E&&$B)!DR)\$G![@)(P>`>2(E^
M($P)\$0!V$B)1A!(BX0DB`(``&1(*P0E*````'0%Z%#4__](@<28`@``6UU!
M7$%=05Y!7\-0OX````#H\]'__[J)J\WON?[<NIB^\.'2PTB)4`@QTDB)2!`Q
MR4C'``$C16=(QT`8=E0R$$B)<"!(B5`H2(E0,(E(>%[#055(8\)!5%5(B<53
M2(G[2(/L&$B+3RB-%,%(.<IS!$C_1S!(P>@=2`%#,$AC0WA,C6,X2(E3*(7`
M=%JZ0````"G".>H/3]5,`>!(8\I(.?!S"TB-/`A(.?YS$`\+2(T\#D@YQG,%
M2#GXZ^Y(B<?SI(M#>`'0B4-X@_A`#X6!````2(G?2(ET)`@IU>@+Z?__2(MT
M)`A,C6MX@_T_?CE).?1(C49`<P5,.>[K"$PYYG,%23G$<J6Y$````$R)YTB)
M1"0(@^U`\Z5(B=_HR^C__TB+="0(Z\)(8\U).?1S"4F-!`Q(.<;K#$PYYG,-
M2(T$#DDYQ`^"8?___TR)Y_.DB6MX2(/$&%M=05Q!7<-!5DR-=CA!54%454B)
M_5-(BT8H2(GS1(MF*$2+;C!(P>@#@^`_00_,00_-C7`!2)A(8];&1`,X@$P!
M\H/^.'XDN4`````QP$B)URGQ\ZI(B=_H..C__[D.````,<!,B??SJ^L.N3@`
M```QP$B)URGQ\ZI$B6MP2(G?1(EC=.@,Z/__2(L#2(G?2,'H&(A%`$B+`TC!
MZ!"(10%(BP.(90)(BP.(10-(BT,(2,'H&(A%!$B+0PA(P>@0B$4%2(M#"(AE
M!DB+0PB(10=(BT,02,'H&(A%"$B+0Q!(P>@0B$4)2(M#$(AE"DB+0Q"(10M(
MBT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&(AE#DB+0QB(10](BT,@2,'H&(A%
M$$B+0R!(P>@0B$412(M#((AE$DB+0R"(11-;74%<05U!7NDYT?__4%C#````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E:2\E<P!005)?5$5-4`!0
M05)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$52
M3$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%2
M7T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X`,0!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``55-%4@!54T52
M3D%-10`E,#)X`'!A<BT`)7,E<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`+G!A<@`E<R5S
M8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`5$5-
M4$1)4@!435``&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-3<`
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@`M90`M+0!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O
M9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-
M04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@
M(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!
M1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY
M("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M
M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I
M<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I
M('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I
M.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T
M;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T
M;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA
M;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N
M86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R
M;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E
M<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!0
M05(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2![
M"F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]
M"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&
M2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A
M8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,
M17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C
M=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@
M)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE
M(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,
M12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L
M("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE
M;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@
M)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID
M96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F
M:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[
M8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I
M;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II
M9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U
M;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*
M;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G
M(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R
M(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P
M:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@
M=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E
M871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L
M"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C
M<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A
M9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X
M="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F
M8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME
M>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]
M("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@
M)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@
M)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M
M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN
M="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN
M=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD
M8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,
M12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=
M*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE
M86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D
M969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^
M;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS
M965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0[
M"GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H
M95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA
M;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F
M9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L
M("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O
M<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA
M;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N
M86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I
M;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T
M;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F
M:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D
M("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]
M?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO
M<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E
M;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D
M<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T
M96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D
M9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S
M>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````0T%#2$4`
M`'!E<FQX<VDN8P````$;`SOH````'````"Q___\$`0``G(+__RP!``"\@O__
M4`4``)&%__]$`0``&8;__XP!``!1AO__I`$``+^&___,`0``08?__^@!``!V
MB/__+`(``%&)__]P`@``[(K__[P"```1B___T`(``$>+___L`@``)XS__Q@#
M```LC/__+`,``-R-__]X`P``!H[__Y`#``#>CO__R`,``""0__\`!```4)#_
M_Q@$``!GD/__,`0``/F0__]\!```#9;___`$``#1E___'`4``!^8__]T!0``
M/J[__\`%``"$KO__V`4``)&O__\0!@``%``````````!>E(``7@0`1L,!PB0
M`0``)````!P````@?O__<`,````.$$8.&$H/"W<(@``_&CLJ,R0B`````!0`
M``!$````:('__Q@``````````````$0```!<````183__X@`````0@X0CP)"
M#AB.`T(.((T$0@XHC`5!#C"&!D,..(,'00Y``FT..$0.,$$.*$(.($(.&$(.
M$$(."!0```"D````A83__S@`````1`X@<PX(`"0```"\````I83__VX`````
M00X0A@)!#AB#`T<.,`)B#AA!#A!!#@@8````Y````.N$__^"`````$<.P`$"
M>@X(````0``````!``!1A?__-0$```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.
M,(,&1P[0`0,=`0XP00XH00X@0@X80@X00@X(``!`````1`$``$*&___;````
M`$(.$(X"4`X8C0-"#B",!$0.*(8%00XP@P9'#L"`!`*R#C!!#BA!#B!"#AA"
M#A!"#@@``$@```"(`0``V8;__YL!````0@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D0..(,'1PY0`WP!#CA!#C!!#BA"#B!"#AA"#A!"#@@````0````U`$`
M`"B(__\E`````````!@```#H`0``.8C__S8`````00X0@P)8#@@````H````
M!`(``%.(___@`````$$.$(8"00X8@P-'#K!``M0.&$$.$$$."````!`````P
M`@``!XG__P4`````````2````$0"``#XB/__L`$```!"#A"/`D(.&(X#0@X@
MC01"#BB,!4$.,(8&2PXX@P=*#N`A`X0!#CA$#C!!#BA"#B!"#AA"#A!"#@@`
M`!0```"0`@``7(K__RH`````1`X@80X(`#0```"H`@``;HK__]@`````00X0
MA@)!#AB#`T<.L"`"BPH.&$@.$$$."$4+<PX800X000X(````-````.`"```.
MB___0@$```!"#A"-`E(.&(P#2`X@A@1(#BB#!4@.,`+_#BA+#B!##AA"#A!"
M#@@4````&`,``!B,__\P`````$$.$&X."``4````,`,``#",__\7`````$$.
M$%4."`!(````2`,``"^,__^2`````$(.$(T"2PX8C`-!#B"&!$<.*(,%00XP
M`F0*#BA$#B!##AA"#A!"#@A%"T$.*$$.($$.&$(.$$(."```<````)0#``!U
MC/__%`4```!"#A"/`DP.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#H`#`IP*
M#CA$#C!!#BA"#B!"#AA"#A!"#@A%"P/@`PZ(`TP.D`--#H@#00Z``P)##CA$
M#C!!#BA"#B!"#AA"#A!"#@@H````"`0``!61___$`0```$(.$(P"2`X8A@-!
M#B"#!`.U`0X800X00@X(`#`````T!```K9+__TX`````00X0A@)!#AB#`T0.
M('H*#AA$#A!!#@A%"T$.&$$.$$$."``@````:`0``&1]__^)`0```$$.$(,"
M1`XP`X`!#A!##@@```!(````C`0``*.2__\?%@```$(.$(\"1PX8C@-"#B"-
M!$(.*(P%00XPA@9!#CB#!T<.T`4#_A4..$$.,$$.*$(.($(.&$(.$$(."```
M%````-@$``!VJ/__1@````!!#A`"1`X(-````/`$``"DJ/__#0$```!"#A"-
M`D4.&(P#00X@A@1$#BB#!4<.0`+S#BA!#B!!#AA"#A!"#@@X````*`4``'FI
M__]"`0```$(.$(X"1@X8C0-"#B",!$$.*(8%1`XP@P8#)P$.*$$.($(.&$(.
M$$(."```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````0"8```````#@)0```````````````````0````````#6`@``````
M``$`````````X0(````````/``````````P$````````#```````````(```
M``````T`````````MU$````````9`````````/"[````````&P`````````(
M`````````!H`````````^+L````````<``````````@`````````]?[_;P``
M```P`P````````4`````````$`T````````&`````````"@$````````"@``
M```````J!`````````L`````````&``````````5````````````````````
M`P````````#HO0````````(`````````$`4````````4``````````<`````
M````%P`````````X$P````````<`````````0!$````````(`````````/@!
M````````"0`````````8`````````!@```````````````````#[__]O````
M``$```@`````^?__;P`````)````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````"+P`````````````````````````````)B``````
M```V(````````$8@````````5B````````!F(````````'8@````````AB``
M``````"6(````````*8@````````MB````````#&(````````-8@````````
MYB````````#V(`````````8A````````%B$````````F(0```````#8A````
M````1B$```````!6(0```````&8A````````=B$```````"&(0```````)8A
M````````IB$```````"V(0```````,8A````````UB$```````#F(0``````
M`/8A````````!B(````````6(@```````"8B````````-B(```````!&(@``
M`````%8B````````9B(```````!V(@```````(8B````````EB(```````"F
M(@```````+8B````````QB(```````#6(@```````.8B````````]B(`````
M```&(P```````!8C````````)B,````````V(P```````$8C````````5B,`
M``````!F(P```````'8C````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````P````````````````````````````````````````.)@
M````````VV`````````38@```````/A@````````&V(`````````````````
M``I005(N<&T*``````````"K8@```````$=#0SH@*$%L<&EN92`Q,BXR+C%?
M9VET,C`R,C`Y,C0M<C0I(#$R+C(N,2`R,#(R,#DR-```+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N9VYU+G!R;W!E<G1Y`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O=``N=&5X
M=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET
M7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD871A+G)E;"YR;P`N9'EN86UI8P`N9&%T
M80`N8G-S`"YC;VUM96YT````````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M``(`````````X`(```````#@`@```````!D````````````````````!````
M````````````````$P````<````"```````````#``````````,````````P
M````````````````````"````````````````````"8```#V__]O`@``````
M```P`P```````#`#````````]``````````$``````````@`````````````
M```````P````"P````(`````````*`0````````H!````````.@(````````
M!0````$````(`````````!@`````````.`````,````"`````````!`-````
M````$`T````````J!````````````````````0```````````````````$``
M```$`````@````````!`$0```````$`1````````^`$````````$````````
M``@`````````&`````````!*````!````$(`````````.!,````````X$P``
M`````!`%````````!````!0````(`````````!@`````````5`````$````&
M```````````@`````````"`````````#`````````````````````0``````
M`````````````$\````!````!@`````````0(````````!`@````````<`,`
M`````````````````!``````````$`````````!:`````0````8`````````
M@",```````"`(P```````!@````````````````````(``````````@`````
M````8P````$````&`````````*`C````````H",````````7+@``````````
M````````$````````````````````&D````!````!@````````"W40``````
M`+=1`````````P````````````````````$```````````````````!O````
M`0````(``````````&``````````8````````.)````````````````````(
M````````````````````=P````$````"`````````.2@````````Y*``````
M``#L````````````````````!````````````````````(4````!`````@``
M``````#0H0```````-"A````````9`4```````````````````@`````````
M``````````"/````#@````,`````````\+L```````#PJP````````@`````
M```````````````(``````````@`````````FP````\````#`````````/B[
M````````^*L````````(````````````````````"``````````(````````
M`*<````!`````P``````````O`````````"L````````"```````````````
M`````!````````````````````"T````!@````,`````````"+P````````(
MK````````.`!````````!0`````````(`````````!``````````7@````$`
M```#`````````.B]````````Z*T````````0`@``````````````````"```
M```````(`````````+T````!`````P``````````P`````````"P````````
M:````````````````````"````````````````````##````"`````,`````
M````@,````````!HL````````+`````````````````````@````````````
M````````R`````$````P````````````````````:+`````````T````````
M`````````````0`````````!``````````$````#````````````````````
L`````)RP````````T0````````````````````$`````````````````````
